@@ -8,18 +8,23 @@ DocMeta.setdocmeta!(LinearSolve, :DocTestSetup, :(using LinearSolve); recursive
 
 include("pages.jl")
 
-makedocs(sitename = "LinearSolve.jl",
+makedocs(
+    sitename = "LinearSolve.jl",
     authors = "Chris Rackauckas",
     modules = [LinearSolve, LinearSolve.SciMLBase],
     clean = true, doctest = false, linkcheck = true,
     warnonly = [:docs_block, :missing_docs],
     linkcheck_ignore = [
-        "https://cli.github.com/manual/installation"
+        "https://cli.github.com/manual/installation",
     ],
-    format = Documenter.HTML(assets = ["assets/favicon.ico"],
-        canonical = "https://docs.sciml.ai/LinearSolve/stable/"),
-    pages = pages)
+    format = Documenter.HTML(
+        assets = ["assets/favicon.ico"],
+        canonical = "https://docs.sciml.ai/LinearSolve/stable/"
+    ),
+    pages = pages
+)
 
 deploydocs(;
     repo = "github.com/SciML/LinearSolve.jl",
-    push_preview = true)
+    push_preview = true
+)
