@@ -18,8 +18,8 @@ function is_cuda_available()
         try
             # Try to detect NVIDIA GPUs via nvidia-smi or similar system indicators
             if haskey(ENV, "CUDA_VISIBLE_DEVICES") ||
-               (Sys.islinux() && isfile("/proc/driver/nvidia/version")) ||
-               (Sys.iswindows() && success(`where nvidia-smi`))
+                    (Sys.islinux() && isfile("/proc/driver/nvidia/version")) ||
+                    (Sys.iswindows() && success(`where nvidia-smi`))
                 @warn "CUDA hardware may be available but CUDA.jl extension is not loaded. Consider adding `using CUDA` to enable GPU algorithms."
             end
         catch
@@ -78,41 +78,41 @@ Returns a Dict with GPU type, count, memory, and compute capability.
 """
 function get_cuda_gpu_info()
     gpu_info = Dict{String, Any}()
-    
+
     # Check if CUDA extension is loaded
     ext = Base.get_extension(LinearSolve, :LinearSolveCUDAExt)
     if ext === nothing
         return gpu_info
     end
-    
+
     try
         # Get CUDA module from the extension
         CUDA = ext.CUDA
-        
+
         # Check if CUDA is functional
         if !CUDA.functional()
             return gpu_info
         end
-        
+
         # Get device information
         devices = collect(CUDA.devices())
         num_devices = length(devices)
-        
+
         if num_devices > 0
             gpu_info["gpu_count"] = num_devices
-            
+
             # Get information from the first GPU
             first_device = devices[1]
             gpu_info["gpu_type"] = CUDA.name(first_device)
-            
+
             # Convert memory from bytes to GB
             total_mem_bytes = CUDA.totalmem(first_device)
-            gpu_info["gpu_memory_gb"] = round(total_mem_bytes / (1024^3), digits=2)
-            
+            gpu_info["gpu_memory_gb"] = round(total_mem_bytes / (1024^3), digits = 2)
+
             # Get compute capability
             capability = CUDA.capability(first_device)
             gpu_info["gpu_capability"] = "$(capability.major).$(capability.minor)"
-            
+
             # If multiple GPUs, list all types
             if num_devices > 1
                 gpu_types = String[]
@@ -126,7 +126,7 @@ function get_cuda_gpu_info()
         # If there's any error, return empty info
         @debug "Error getting CUDA GPU info: $e"
     end
-    
+
     return gpu_info
 end
 
@@ -138,26 +138,26 @@ Returns a Dict with GPU type and count.
 """
 function get_metal_gpu_info()
     gpu_info = Dict{String, Any}()
-    
+
     # Check if Metal extension is loaded
     ext = Base.get_extension(LinearSolve, :LinearSolveMetalExt)
     if ext === nothing
         return gpu_info
     end
-    
+
     try
         # Get Metal module from the extension
         Metal = ext.Metal
-        
+
         # Check if Metal is functional
         if !Metal.functional()
             return gpu_info
         end
-        
+
         # Get device information
         # Metal typically has one device on Apple Silicon
         gpu_info["gpu_count"] = 1
-        
+
         # Determine GPU type based on system architecture
         if Sys.ARCH == :aarch64
             # Try to get more specific model information
@@ -166,7 +166,7 @@ function get_metal_gpu_info()
             if !isempty(cpu_info)
                 cpu_model = cpu_info[1].model
             end
-            
+
             # Infer GPU type from CPU model for Apple Silicon
             if contains(lowercase(cpu_model), "m1")
                 gpu_info["gpu_type"] = "Apple M1 GPU"
@@ -186,7 +186,7 @@ function get_metal_gpu_info()
         # If there's any error, return empty info
         @debug "Error getting Metal GPU info: $e"
     end
-    
+
     return gpu_info
 end
 
@@ -202,14 +202,14 @@ function get_system_info()
     info["os"] = string(Sys.KERNEL)
     info["os_name"] = Sys.iswindows() ? "Windows" : Sys.islinux() ? "Linux" : Sys.isapple() ? "macOS" : "Other"
     info["arch"] = string(Sys.ARCH)
-    
+
     # Get detailed CPU information from Sys.cpu_info()
     cpu_info = Sys.cpu_info()
     if !isempty(cpu_info)
         first_cpu = cpu_info[1]
         info["cpu_model"] = first_cpu.model
         info["cpu_speed_mhz"] = first_cpu.speed
-        
+
         # Count unique CPU models (for heterogeneous systems)
         cpu_models = unique([cpu.model for cpu in cpu_info])
         if length(cpu_models) > 1
@@ -222,7 +222,7 @@ function get_system_info()
         info["cpu_model"] = "Unknown"
         info["cpu_speed_mhz"] = 0
     end
-    
+
     # Legacy CPU name for backward compatibility
     try
         info["cpu_name"] = string(Sys.CPU_NAME)
@@ -230,23 +230,23 @@ function get_system_info()
         # Fallback to cpu_model if CPU_NAME not available
         info["cpu_name"] = get(info, "cpu_model", "Unknown")
     end
-    
+
     # CPUSummary.num_cores() returns the physical cores (as Static.StaticInt)
     info["num_cores"] = Int(CPUSummary.num_cores())
     info["num_logical_cores"] = Sys.CPU_THREADS
     info["num_threads"] = Threads.nthreads()
-    
+
     # BLAS threads
     try
         info["blas_num_threads"] = LinearAlgebra.BLAS.get_num_threads()
     catch
         info["blas_num_threads"] = 1
     end
-    
+
     info["blas_vendor"] = string(LinearAlgebra.BLAS.vendor())
     info["has_cuda"] = is_cuda_available()
     info["has_metal"] = is_metal_available()
-    
+
     # Get GPU information if CUDA is available
     if info["has_cuda"]
         gpu_info = get_cuda_gpu_info()
@@ -257,7 +257,7 @@ function get_system_info()
             info["gpu_capability"] = gpu_info["gpu_capability"]
         end
     end
-    
+
     # Get GPU information if Metal is available
     if info["has_metal"]
         metal_info = get_metal_gpu_info()
@@ -281,7 +281,7 @@ function get_system_info()
 
     # Add package versions
     info["package_versions"] = get_package_versions()
-    
+
     return info
 end
 
@@ -293,10 +293,10 @@ Returns a Dict with package names and versions.
 """
 function get_package_versions()
     versions = Dict{String, String}()
-    
+
     # Get the current project's dependencies
     deps = Pkg.dependencies()
-    
+
     # List of packages we're interested in tracking
     important_packages = [
         "LinearSolve",
@@ -317,9 +317,9 @@ function get_package_versions()
         "IterativeSolvers",
         "Krylov",
         "KrylovKit",
-        "LinearAlgebra"
+        "LinearAlgebra",
     ]
-    
+
     # Also track JLL packages for BLAS libraries
     jll_packages = [
         "MKL_jll",
@@ -327,11 +327,11 @@ function get_package_versions()
         "OpenBLAS32_jll",
         "blis_jll",
         "LAPACK_jll",
-        "CompilerSupportLibraries_jll"
+        "CompilerSupportLibraries_jll",
     ]
-    
+
     all_packages = union(important_packages, jll_packages)
-    
+
     # Iterate through dependencies and collect versions
     for (uuid, dep) in deps
         if dep.name in all_packages
@@ -352,14 +352,14 @@ function get_package_versions()
             end
         end
     end
-    
+
     # Try to get Julia's LinearAlgebra stdlib version
     try
         versions["LinearAlgebra"] = string(VERSION)  # Stdlib version matches Julia
     catch
         versions["LinearAlgebra"] = "stdlib"
     end
-    
+
     # Get BLAS configuration info
     try
         blas_config = LinearAlgebra.BLAS.get_config()
@@ -376,7 +376,7 @@ function get_package_versions()
         # Fallback for older Julia versions
         versions["BLAS_vendor"] = string(LinearAlgebra.BLAS.vendor())
     end
-    
+
     return versions
 end
 
@@ -389,74 +389,74 @@ Includes versioninfo() details and hardware-specific information for analysis.
 function get_detailed_system_info()
     # Basic system information
     system_data = Dict{String, Any}()
-    
+
     # Julia and system basics - all with safe fallbacks
     try
         system_data["timestamp"] = string(Dates.now())
     catch
         system_data["timestamp"] = "unknown"
     end
-    
+
     try
         system_data["julia_version"] = string(VERSION)
     catch
         system_data["julia_version"] = "unknown"
     end
-    
+
     try
         system_data["julia_commit"] = Base.GIT_VERSION_INFO.commit[1:10]  # Short commit hash
     catch
         system_data["julia_commit"] = "unknown"
     end
-    
+
     try
         system_data["os_name"] = Sys.iswindows() ? "Windows" : Sys.islinux() ? "Linux" : Sys.isapple() ? "macOS" : "Other"
     catch
         system_data["os_name"] = "unknown"
     end
-    
+
     try
         system_data["os_version"] = string(Sys.KERNEL)
     catch
         system_data["os_version"] = "unknown"
     end
-    
+
     try
         system_data["architecture"] = string(Sys.ARCH)
     catch
         system_data["architecture"] = "unknown"
     end
-    
+
     try
         system_data["cpu_cores"] = Int(CPUSummary.num_cores())
     catch
         system_data["cpu_cores"] = "unknown"
     end
-    
+
     try
         system_data["cpu_logical_cores"] = Sys.CPU_THREADS
     catch
         system_data["cpu_logical_cores"] = "unknown"
     end
-    
+
     try
         system_data["julia_threads"] = Threads.nthreads()
     catch
         system_data["julia_threads"] = "unknown"
     end
-    
+
     try
         system_data["word_size"] = Sys.WORD_SIZE
     catch
         system_data["word_size"] = "unknown"
     end
-    
+
     try
         system_data["machine"] = Sys.MACHINE
     catch
         system_data["machine"] = "unknown"
     end
-    
+
     # CPU details from Sys.cpu_info()
     try
         cpu_info = Sys.cpu_info()
@@ -464,7 +464,7 @@ function get_detailed_system_info()
             first_cpu = cpu_info[1]
             system_data["cpu_model"] = first_cpu.model
             system_data["cpu_speed_mhz"] = first_cpu.speed
-            
+
             # Check for heterogeneous CPUs
             cpu_models = unique([cpu.model for cpu in cpu_info])
             if length(cpu_models) > 1
@@ -473,11 +473,11 @@ function get_detailed_system_info()
             else
                 system_data["heterogeneous_cpus"] = false
             end
-            
+
             # Calculate average CPU speed if speeds vary
             cpu_speeds = [cpu.speed for cpu in cpu_info]
             if length(unique(cpu_speeds)) > 1
-                system_data["cpu_speed_avg_mhz"] = round(mean(cpu_speeds), digits=0)
+                system_data["cpu_speed_avg_mhz"] = round(mean(cpu_speeds), digits = 0)
                 system_data["cpu_speed_min_mhz"] = minimum(cpu_speeds)
                 system_data["cpu_speed_max_mhz"] = maximum(cpu_speeds)
             end
@@ -489,7 +489,7 @@ function get_detailed_system_info()
         system_data["cpu_model"] = "unknown"
         system_data["cpu_speed_mhz"] = 0
     end
-    
+
     # Legacy CPU name for backward compatibility
     try
         system_data["cpu_name"] = string(Sys.CPU_NAME)
@@ -497,14 +497,14 @@ function get_detailed_system_info()
         # Fallback to cpu_model if available
         system_data["cpu_name"] = get(system_data, "cpu_model", "unknown")
     end
-    
+
     try
         # Architecture info from Sys
         system_data["cpu_architecture"] = string(Sys.ARCH)
     catch
         system_data["cpu_architecture"] = "unknown"
     end
-    
+
     # Categorize CPU vendor for easy analysis
     try
         cpu_name_lower = lowercase(string(system_data["cpu_name"]))
@@ -520,14 +520,14 @@ function get_detailed_system_info()
     catch
         system_data["cpu_vendor"] = "unknown"
     end
-    
+
     # BLAS and linear algebra libraries
     try
         system_data["blas_vendor"] = string(LinearAlgebra.BLAS.vendor())
     catch
         system_data["blas_vendor"] = "unknown"
     end
-    
+
     # LAPACK vendor detection (safe for different Julia versions)
     try
         system_data["lapack_vendor"] = string(LinearAlgebra.LAPACK.vendor())
@@ -535,52 +535,52 @@ function get_detailed_system_info()
         # Fallback: LAPACK vendor often matches BLAS vendor
         system_data["lapack_vendor"] = get(system_data, "blas_vendor", "unknown")
     end
-    
+
     try
         system_data["blas_num_threads"] = LinearAlgebra.BLAS.get_num_threads()
     catch
         system_data["blas_num_threads"] = "unknown"
     end
-    
+
     # LinearSolve-specific package availability
     try
         system_data["mkl_available"] = MKL_jll.is_available()
     catch
         system_data["mkl_available"] = false
     end
-    
+
     try
         system_data["mkl_used"] = system_data["mkl_available"] && contains(lowercase(string(system_data["blas_vendor"])), "mkl")
     catch
         system_data["mkl_used"] = false
     end
-    
+
     try
         system_data["apple_accelerate_available"] = LinearSolve.appleaccelerate_isavailable()
     catch
         system_data["apple_accelerate_available"] = false
     end
-    
+
     try
         system_data["apple_accelerate_used"] = system_data["apple_accelerate_available"] && contains(lowercase(string(system_data["blas_vendor"])), "accelerate")
     catch
         system_data["apple_accelerate_used"] = false
     end
-    
+
     # BLIS availability check - based on JLL packages
     system_data["blis_available"] = false
     system_data["blis_used"] = false
     system_data["blis_jll_loaded"] = false
     system_data["lapack_jll_loaded"] = false
-    
+
     try
         # Check if BLIS_jll and LAPACK_jll are loaded
         system_data["blis_jll_loaded"] = haskey(Base.loaded_modules, Base.PkgId(Base.UUID("068f7417-6964-5086-9a5b-bc0c5b4f7fa6"), "BLIS_jll"))
         system_data["lapack_jll_loaded"] = haskey(Base.loaded_modules, Base.PkgId(Base.UUID("51474c39-65e3-53ba-86ba-03b1b862ec14"), "LAPACK_jll"))
-        
+
         # BLIS is available if JLL packages are loaded and BLISLUFactorization exists
-        if (system_data["blis_jll_loaded"] || system_data["lapack_jll_loaded"]) && 
-           isdefined(LinearSolve, :BLISLUFactorization) && hasmethod(LinearSolve.BLISLUFactorization, ())
+        if (system_data["blis_jll_loaded"] || system_data["lapack_jll_loaded"]) &&
+                isdefined(LinearSolve, :BLISLUFactorization) && hasmethod(LinearSolve.BLISLUFactorization, ())
             system_data["blis_available"] = true
             # Check if BLIS is actually being used (contains "blis" in BLAS vendor)
             system_data["blis_used"] = contains(lowercase(string(system_data["blas_vendor"])), "blis")
@@ -588,20 +588,20 @@ function get_detailed_system_info()
     catch
         # If there's any error checking BLIS JLL packages, leave as false
     end
-    
+
     # GPU information
     try
         system_data["cuda_available"] = is_cuda_available()
     catch
         system_data["cuda_available"] = false
     end
-    
+
     try
         system_data["metal_available"] = is_metal_available()
     catch
         system_data["metal_available"] = false
     end
-    
+
     # Get detailed GPU information if available
     if system_data["cuda_available"]
         gpu_info = get_cuda_gpu_info()
@@ -621,7 +621,7 @@ function get_detailed_system_info()
             system_data["gpu_count"] = metal_info["gpu_count"]
         end
     end
-    
+
     # Try to detect if CUDA/Metal packages are actually loaded
     system_data["cuda_loaded"] = false
     system_data["metal_loaded"] = false
@@ -636,14 +636,14 @@ function get_detailed_system_info()
     catch
         # If we can't detect, leave as false
     end
-    
+
     # Environment information
     try
         system_data["libm"] = Base.libm_name
     catch
         system_data["libm"] = "unknown"
     end
-    
+
     # libdl_name may not exist in all Julia versions
     try
         system_data["libdl"] = Base.libdl_name
@@ -657,20 +657,20 @@ function get_detailed_system_info()
             meminfo = read(`cat /proc/meminfo`, String)
             mem_match = match(r"MemTotal:\s*(\d+)\s*kB", meminfo)
             if mem_match !== nothing
-                system_data["total_memory_gb"] = round(parse(Int, mem_match.captures[1]) / 1024 / 1024, digits=2)
+                system_data["total_memory_gb"] = round(parse(Int, mem_match.captures[1]) / 1024 / 1024, digits = 2)
             else
                 system_data["total_memory_gb"] = "unknown"
             end
         elseif Sys.isapple()
             mem_bytes = parse(Int, read(`sysctl -n hw.memsize`, String))
-            system_data["total_memory_gb"] = round(mem_bytes / 1024^3, digits=2)
+            system_data["total_memory_gb"] = round(mem_bytes / 1024^3, digits = 2)
         else
             system_data["total_memory_gb"] = "unknown"
         end
     catch
         system_data["total_memory_gb"] = "unknown"
     end
-    
+
     # Create DataFrame with single row
     return DataFrame([system_data])
 end
